#include "PluginProcessor.h"
#include "PluginEditor.h"

#define WIDTH 400
#define HEIGHT 300

//==============================================================================
AudioPluginAudioProcessorEditor::AudioPluginAudioProcessorEditor (AudioPluginAudioProcessor& p)
    : AudioProcessorEditor (&p), processorRef (p)
{
    juce::ignoreUnused (processorRef);
    // Make sure that before the constructor has finished, you've set the
    // editor's size to whatever you need it to be.
    setSize (WIDTH, HEIGHT);
    setResizable(true, true);
    setResizeLimits(WIDTH, HEIGHT, WIDTH*3, HEIGHT*3);

    addAndMakeVisible(editorComponent);
}

AudioPluginAudioProcessorEditor::~AudioPluginAudioProcessorEditor()
{
}

//==============================================================================
void AudioPluginAudioProcessorEditor::paint (juce::Graphics& g)
{
    
}

void AudioPluginAudioProcessorEditor::resized()
{
    // This is generally where you'll want to lay out the positions of any
    // subcomponents in your editor..

    const auto newScale = float(getHeight()) / HEIGHT;

    editorComponent.setTransform(juce::AffineTransform::scale(newScale));
}

EditorComponent::EditorComponent()
{
    setSize(WIDTH, HEIGHT);
    int spacing = WIDTH / NUMLIGHTS;

    for (int i = 0; i < NUMLIGHTS; i++)
    {
        addAndMakeVisible(lights[i]);
        lights[i].setBounds(i * spacing, HEIGHT/2, 32, 32);
    }
}

void EditorComponent::paint(juce::Graphics& g)
{
    // (Our component is opaque, so we must completely fill the background with a solid colour)
    g.fillAll(getLookAndFeel().findColour(juce::ResizableWindow::backgroundColourId));

    g.setColour(juce::Colours::white);
    g.setFont(15.0f);
    g.drawFittedText("Hello World!", getLocalBounds(), juce::Justification::centred, 1);
}

LightComponent::LightComponent()
{
    setSize(32, 32);
    setRepaintsOnMouseActivity(true);
}

void LightComponent::paint(juce::Graphics& g)
{
    if (isMouseOver(true)) g.setColour(juce::Colours::red);
    else g.setColour(juce::Colours::green);
    g.fillEllipse(8, 8, 16, 16);
}
